@@ -128,7 +128,7 @@ class MyWhatify:
     @classmethod
     def run_prediction(cls, data_name, ensemble_id, data_file=None, wait=True, file_path=None, header=None, data_id=None):
         with allure.step('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait)):
-            print('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
+            print('running the prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
             logging.info('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
             status = True
             predict_id = None
@@ -570,12 +570,8 @@ class MyWhatify:
 
     @classmethod
     def get_data_file_s3(cls, data_name='car_sdk_demo.csv'):
-        logging.info('getting csv from data file for data_name: ' + str(data_name))
-        script_dir = os.path.dirname(__file__)
-        path = os.path.join(script_dir, '../data_source/')
-        path = "s3://firefly-automation/whatify_demo/"
-        # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
-        return pd.read_csv(path + data_name)
+        logging.info('getting csv from data file from S3 for data_name: ' + str(data_name))
+        return cls.read_to_pandas_df(file_name=data_name)
 
     @classmethod
     def get_data_file(cls, data_name='car_sdk_demo.csv'):
@@ -583,7 +579,6 @@ class MyWhatify:
             # script_dir = os.getcwd()
             # script_dir = os.path.dirname(__file__)
             path = os.path.join(os.path.dirname(__file__), 'data_source/', data_name)
-            # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
         return pd.read_csv(path)
 
     @classmethod
